==> 90002.22.tar.gz: zz_money/locale_ruRU.lua <==
local addonname, addon = ...
local name = "zz_Money"
local L = LibStub("AceLocale-3.0"):NewLocale(name, "ruRU", false)
if L then
	L[name] = name
	L[name..' Settings'] = name..' Настройки'
	L['Sitzung']='Сессия'
	L['Einnahmen']='Доход'
	L['Ausgaben']='Расход'
	L['Heute']='Сегодня'
	L['Gestern']='Вчера'
	L['7-Tage']='7-Дней'
	L['Gesamt']='Всего'
	L['Bankier']='Банкир'
	L['Goldgrenze']='Лимит золота'
	L['Sende'] = 'Отправить'
	L['Subject'] = 'Лишнее золото'
	L['Minimum Limit']='Минимальный лимит'
	L['Desc MinL']='Персонажи с золотом меньше указанного значения будут показаны банкиру'
	L['Maximum Limit']='Максимальный лимит'
	L['Desc MaxL']='Персонажи с золотом больше указанного лимита будут видеть кнопку для отправки избытка золота банкиру'
	L['Empfaenger']='Бенефициар'
	L['Fail']='Не удалось отправить письмо'
	L['Success']=function(name,sum) return format("Sent %s to %s",addon:buildMoneyString(sum,nil,{ ['iconSize'] = addon['db']['global']['iconSize'] or 12}),name) end
	L['iconSize']='Размер монеты'
	L['sortDir'] = 'Сортировка Верх/Низ'
	L['nobanker'] = 'Отключить функцию банкира'
	L['neutral'] = 'Отключено пока не выбрана фракция'
	L['accountMoney'] = 'Золота на аккаунте'
	L['accountMoneyDesc'] = 'Показать все золото на аккаунте'
	L['shortMoney'] = 'Показывать только золото'
	L['abrevK'] = "Сокращать золото до тысяч"
	L['abrevM'] = "Сокращать золото до миллионов"
	L['abrK'] = "k"
	L['abrM'] = "m"
	L['connectedRealms'] = "List connected Realms"
	L['DeleteChar'] = "Delete Char"
	L['DeleteCharDesc'] = "Removes all data for this character"
	L['DeleteCharOk'] = "Yes, I'm sure!"
end

==> 90005.25.tar.gz: zz_money/locale_ruRU.lua <==
local addonname, addon = ...
local name = "zz_Money"
local L = LibStub("AceLocale-3.0"):NewLocale(name, "ruRU", false)
if L then
	L[name] = name
	L[name..' Settings'] = name..' Настройки'
	L['Sitzung']='Сессия'
	L['Einnahmen']='Доход'
	L['Ausgaben']='Расход'
	L['Heute']='Сегодня'
	L['Gestern']='Вчера'
	L['7-Tage']='7-Дней'
	L['Gesamt']='Всего'
	L['Bankier']='Банкир'
	L['Goldgrenze']='Лимит золота'
	L['Sende'] = 'Отправить'
	L['Subject'] = 'Лишнее золото'
	L['Minimum Limit']='Минимальный лимит'
	L['Desc MinL']='Персонажи с золотом меньше указанного значения будут показаны банкиру'
	L['Maximum Limit']='Максимальный лимит'
	L['Desc MaxL']='Персонажи с золотом больше указанного лимита будут видеть кнопку для отправки избытка золота банкиру'
	L['Empfaenger']='Бенефициар'
	L['Fail']='Не удалось отправить письмо'
	L['Success']=function(name,sum) return format("Sent %s to %s", GetCoinTextureString(sum), name) end
	L['iconSize']='Размер монеты'
	L['sortDir'] = 'Сортировка Верх/Низ'
	L['nobanker'] = 'Отключить функцию банкира'
	L['neutral'] = 'Отключено пока не выбрана фракция'
	L['accountMoney'] = 'Золота на аккаунте'
	L['accountMoneyDesc'] = 'Показать все золото на аккаунте'
	L['shortMoney'] = 'Показывать только золото'
	L['shortMoneyTip'] = 'Shorten money in tooltip'
	L['abrevK'] = "Сокращать золото до тысяч"
	L['abrevM'] = "Сокращать золото до миллионов"
	L['abrK'] = "k"
	L['abrM'] = "m"
	L['connectedRealms'] = "List connected Realms"
	L['DeleteChar'] = "Delete Char"
	L['DeleteCharDesc'] = "Removes all data for this character"
	L['DeleteCharOk'] = "Yes, I'm sure!"
	L['showLog'] = "Log changes in chat"
end
